"""Provides package-level metadata for cloud-autopkg-runner.

This module defines variables that expose key information about the
cloud-autopkg-runner package, such as the package version. This
information can be accessed programmatically to determine the
installed version of the library.
"""

__version__ = "0.5.5"
